/*----------------------------------------------------------------------*\

    current

\*----------------------------------------------------------------------*/
#include "current.h"

/* IMPORTS */


/* CONSTANTS */


/* PUBLIC DATA */
CurVars current;
bool gameStateChanged = false;



/* PRIVATE TYPES & DATA */


/*+++++++++++++++++++++++++++++++++++++++++++++++++++*/
